.. cnlp_transformers documentation master file, created by
   sphinx-quickstart on Thu Feb 17 18:28:22 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to cnlp_transformers's documentation!
=============================================

.. automodule:: cnlpt
    :members:

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   cnlpt


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
